@@ -104,7 +104,7 @@ except ImportError:
                 " install ordereddict 1.1 from pypi for python2.6")
 
 __pkgname__ = 'python-crontab'
-__version__ = '2.2.2'
+__version__ = '2.2.3'
 
 ITEMREX = re.compile(r'^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)'
                      r'\s+([^@#\s]+)\s+([^#\n]*)(\s+#\s*([^\n]*)|$)')
@@ -450,9 +450,19 @@ class CronTab(object):
 
     def _remove(self, item):
         """Internal removal of an item"""
-        # The last item often has a trailing line feed
-        if self.crons[-1] == item and self.lines[-1] == '':
-            self.lines.remove(self.lines[-1])
+        # Manage siblings when items are deleted
+        for sibling in self.lines[self.lines.index(item)+1:]:
+            if isinstance(sibling, CronItem):
+                env = sibling.env
+                sibling.env = item.env
+                sibling.env.update(env)
+                sibling.env.job = sibling
+                break
+            elif sibling == '':
+                self.lines.remove(sibling)
+            else:
+                break
+
         self.crons.remove(item)
         self.lines.remove(item)
         return 1
